@@ -18,18 +18,16 @@ __docformat__ = "reStructuredText"
 import zope.component
 import zope.contenttype.parse
 import zope.interface
+
 import zope.mimetype.interfaces
 
 
-class ContentInfo(object):
+@zope.interface.implementer(zope.mimetype.interfaces.IContentInfo)
+@zope.component.adapter(zope.interface.Interface)
+class ContentInfo:
     """Basic IContentInfo that provides information from an IContentTypeAware.
     """
 
-    zope.interface.implements(
-        zope.mimetype.interfaces.IContentInfo)
-    zope.component.adapts(
-        zope.interface.Interface)
-
     def __init__(self, context):
         self.context = context
         aware = zope.mimetype.interfaces.IContentTypeAware(context)
