@@ -10,7 +10,7 @@ available for some of the titles.
 The implementation ignores these issues for now.
 
 """
-from __future__ import absolute_import
+
 
 __docformat__ = "reStructuredText"
 
@@ -22,7 +22,7 @@ class TranslatableSourceSelectWidget(
         zope.formlib.source.SourceSelectWidget):
 
     def __init__(self, field, source, request):
-        super(TranslatableSourceSelectWidget, self).__init__(
+        super().__init__(
             field, source, request)
         self.displays = {}   # value --> (display, token)
         self.order = []      # values in sorted order
@@ -53,7 +53,8 @@ class TranslatableSourceSelectWidget(
         missing = self._toFormValue(self.context.missing_value)
 
         if self._displayItemForMissingValue and not self.context.required:
-            render = self.renderSelectedItem if missing in values else self.renderItem
+            render = (self.renderSelectedItem if missing in values
+                      else self.renderItem)
 
             missing_item = render(
                 count,
@@ -68,7 +69,8 @@ class TranslatableSourceSelectWidget(
         for value in self.order:
             item_text, token = self.displays[value]
 
-            render = self.renderSelectedItem if value in values else self.renderItem
+            render = (self.renderSelectedItem if value in values
+                      else self.renderItem)
 
             rendered_item = render(
                 count,
