@@ -13,24 +13,25 @@
 
 import os.path
 
-from zope import interface
-from zope import schema
 from zope.configuration import fields
 
-from zope.mimetype.i18n import _
+from zope import interface
+from zope import schema
 from zope.mimetype import codec
 from zope.mimetype import interfaces
 from zope.mimetype import mtypes
+from zope.mimetype.i18n import _
+
 
 try:
     from zope.browserresource.metaconfigure import icon
-except ImportError: # pragma: no cover (coverage runs with the extra installed)
+except ImportError:  # pragma: no cover
     def icon(*args):
         import warnings
         warnings.warn("No icon support: zope.browserresource is not installed")
 
-import zope.component.zcml
 import zope.component.interface
+import zope.component.zcml
 
 
 class IMimeTypesDirective(interface.Interface):
@@ -46,14 +47,14 @@ class IMimeTypesDirective(interface.Interface):
         title=_("File"),
         description=_("Path of the CSV file to load registrations from."),
         required=True,
-        )
+    )
 
     module = fields.GlobalObject(
         title=_("Module"),
         description=_("Module which contains the interfaces"
                       " referenced from the CSV file."),
         required=True,
-        )
+    )
 
 
 def mimeTypesDirective(_context, file, module):
@@ -70,18 +71,18 @@ def mimeTypesDirective(_context, file, module):
             setattr(module, name, iface)
         # Register the interface as a utility:
         _context.action(
-            discriminator = None,
-            callable = zope.component.interface.provideInterface,
-            args = (iface.__module__ + '.' + iface.getName(), iface)
-            )
+            discriminator=None,
+            callable=zope.component.interface.provideInterface,
+            args=(iface.__module__ + '.' + iface.getName(), iface)
+        )
         for mime_type in info[2]:
             # Register the interface as the IContentTypeInterface
             # utility for each appropriate MIME type:
             _context.action(
-                discriminator = ('utility', provides, mime_type),
-                callable = zope.component.zcml.handler,
-                args = ('registerUtility', iface, provides, mime_type),
-                )
+                discriminator=('utility', provides, mime_type),
+                callable=zope.component.zcml.handler,
+                args=('registerUtility', iface, provides, mime_type),
+            )
         icon_path = os.path.join(directory, info[3])
         if icon_path and os.path.isfile(icon_path):
             icon(_context, "zmi_icon", iface, icon_path)
@@ -101,13 +102,14 @@ class ICodecDirective(interface.Interface):
         title=_('Name'),
         description=_('The name of the Python codec.'),
         required=True,
-        )
+    )
 
     title = fields.MessageID(
         title=_('Title'),
         description=_('The human-readable name for this codec.'),
         required=False,
-        )
+    )
+
 
 class ICharsetDirective(interface.Interface):
     """Defines a charset in a codec.
@@ -123,28 +125,28 @@ class ICharsetDirective(interface.Interface):
         title=_('Name'),
         description=_('The name of the Python codec.'),
         required=True,
-        )
+    )
 
     preferred = schema.Bool(
         title=_('Preferred'),
         description=_('Is this is the preferred charset for the encoding.'),
         required=False,
-        )
+    )
 
 
-class CodecDirective(object):
+class CodecDirective:
     def __init__(self, _context, name, title):
         self.name = name
         self.title = title
         _context.action(
-            discriminator = None,
-            callable = codec.addCodec,
-            args = (name, title),
-            )
+            discriminator=None,
+            callable=codec.addCodec,
+            args=(name, title),
+        )
 
     def charset(self, _context, name, preferred=False):
         _context.action(
-            discriminator = (self.name, name),
-            callable = codec.addCharset,
-            args = (self.name, name, preferred),
-            )
+            discriminator=(self.name, name),
+            callable=codec.addCharset,
+            args=(self.name, name, preferred),
+        )
